DevicePairConfig

Struct DevicePairConfig 

pub struct DevicePairConfig {
    pub base: Option<BaseDeviceConfig>,
    pub fallible_transmit_left: Option<bool>,
    pub fallible_transmit_right: Option<bool>,
    /* private fields */
}

Fields

base: Option<BaseDeviceConfig>

Base device configuration.

It not set, interpreted as an empty table.

fallible_transmit_left: Option<bool>

If true, transmit buffers on the left end are dropped if no receive buffers are available on the right end to receive it. Otherwise, transmit buffers wait until a receive buffer is available to copy them to.

It not set, interpreted as false.

fallible_transmit_right: Option<bool>

Like fallible_transmit_left but allows writes to the right end to be fallible.

It not set, interpreted as false.